#!/bin/ksh
#
# ITMOracle_init_tbsm.sh v1.0
#
# Description: Initialize TBSM for IBM Tivoli Monitoring for Databases, Version 5.1.0 - Oracle 
#
# NOTE: Must be run on the TBSM server under from the MKS Korn shell.
#
#              Define object class, icon image, task library and lines
#              of business using TBSM commands.  The TBSM commands will
#              print messages to stdout.
#
#              The directory that contains this script must also contain 
#              the IMAGEFILENAME and the TLLFILENAME.
#
#              This script must be run on the TBSM server under the MKS 
#              Korn shell.
#
# (C) COPYRIGHT IBM, Inc. 2002
# All Rights Reserved
# Licensed Material - Property of IBM, Inc.
#
# Parameters:
# -S hostname of the sql server
# -U user id
# -P password

COMPANY="IBM"

SOFTCOMP="OracleInstanceManager OracleDatabaseManager" 
SOFTCOMP_VERSIONS="7.3.4 8.0.4 8.0.5 8.1.5 8.1.6 8.1.7 9.0.1 9.0.2 9.2.0 unknown"		
	
SM_INSTIMAGEFILENAME="tv_oracle_database_instance_24.gif"
LG_INSTIMAGEFILENAME="tv_oracle_database_instance_45.gif"
SM_DBIMAGEFILENAME="tv_oracle_database_24.gif"
LG_DBIMAGEFILENAME="tv_oracle_database_45.gif"

PARENTLOBNAME="IBM"
LOBNAME="Oracle Databases"

# Exit if non-zero return code
# TBSM scripts will explain the error

function checkrc {
	if [ $1 -ne 0 ]
	then
		exit $1
	fi
}

# Create a working directory and copy our files there
# Set log 
WORKDIR="C:/temp/CTO"
LOG="${WORKDIR}/trace_ITMOracle_init_TBSM.log"
if [ ! -d $WORKDIR ] 
then
	mkdir $WORKDIR
	checkrc $?
fi

exec 2>$LOG
set -x

cp $SM_INSTIMAGEFILENAME $WORKDIR
cp $LG_INSTIMAGEFILENAME $WORKDIR
cp $SM_DBIMAGEFILENAME $WORKDIR
cp $LG_DBIMAGEFILENAME $WORKDIR

cd $WORKDIR

# Set directory names based on where TBSM is installed
TBSMDIR=`reg query 'HKLM\Software\Accessible Software, Inc.\Access1\1.0\InstallDirectory' | sed 's/^.*InstallDirectory[        ]*//'`
if [ -z "$TBSMDIR" ]
then 
    # d163529 FP3DIVT:ITMOracle_ini_tbsm.sh failed due to reg.exe command
    # windows 2000 resource kit reg.exe usage and output has changed.. 
    # sample output:
    #
    # $ reg query 'HKLM\Software\Accessible Software, Inc.\Access1\1.0' /v InstallDirectory
    #
    # ! REG.EXE VERSION 2.0
    #
    #HKEY_LOCAL_MACHINE\Software\Accessible Software, Inc.\Access1\1.0
    #    InstallDirectory    REG_SZ  C:\TivoliManager
    #
    #
    # if the first reg.exe command failed to get the TBSM install directory, try this command,
    TBSMDIR=`reg query 'HKLM\Software\Accessible Software, Inc.\Access1\1.0' /v InstallDirectory | sed -n '/.*InstallDirectory.*/p' | awk '{print $3}'`
fi
echo "TBSM dir is $TBSMDIR"

TBSMBINDIR="${TBSMDIR}/bin"
TLLBINDIR="${TBSMDIR}/xdfparser/bin"

PATH="$PATH;$TBSMBINDIR;$TLLBINDIR"
export PATH

# Check Usage
# On failure, use a TBSM translated message but strip out the []. 
# Our usage is:
#
# $0 -S server -U userid -P password

if [ "$1" != "-S" ] || [ "$3" != "-U" ] || [ "$5" != "-P" ] || [ "$6" = "" ]
then
	echo
	${TBSMBINDIR}/ASIShellMsg ASILobScripts 15 $0 | sed 's/\[//g' | sed 's/\]//g'
	echo
	exit 1
fi

# We will pass in all the command line arguments to each command that needs them
set +x
args="$*"
# Do not put real password in the logs
log_args="$1 $2 $3 $4 $5 xxxxxxxx"
set -x

# Create Line of Business before looping

echo "${TBSMBINDIR}/addLOB.sh -l $LOBNAME -p $PARENTLOBNAME $log_args"
set +x
RESULT=`${TBSMBINDIR}/addLOB.sh -l "$LOBNAME" -p "$PARENTLOBNAME" $args`
rc=$?
echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
set -x
checkrc $rc

# Loop for each Software Component Version
for scomp in $SOFTCOMP
do

	for sver in $SOFTCOMP_VERSIONS
	do
   
		# Define software components
		echo "${TBSMBINDIR}/gemgenprod.sh -m $COMPANY -p $scomp -v $sver $log_args"
		set +x
		RESULT=`${TBSMBINDIR}/gemgenprod.sh -m "$COMPANY" -p "$scomp" -v "$sver" $args`
		rc=$?
		echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
		set -x
		checkrc $rc

		# Import images for icons
		if [ "$scomp" = "OracleDatabaseManager" ]; then
			echo "${TBSMBINDIR}/gemimageimport.sh -p $scomp -v $sver -s -i $SM_DBIMAGEFILENAME $log_args"
			set +x 
			RESULT=`${TBSMBINDIR}/gemimageimport.sh -p "$scomp" -v "$sver" -s -i "$SM_DBIMAGEFILENAME" $args`
			rc=$?
 			echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
			set -x
			checkrc $rc

			echo "${TBSMBINDIR}/gemimageimport.sh -p $scomp -v $sver -l -i $LG_DBIMAGEFILENAME $log_args" 
			set +x 
			RESULT=`${TBSMBINDIR}/gemimageimport.sh -p "$scomp" -v "$sver" -l -i "$LG_DBIMAGEFILENAME" $args` 
			rc=$?
			echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
  			set -x
  			checkrc $rc

		elif [ "$scomp" = "OracleInstanceManager" ]; then
			echo "${TBSMBINDIR}/gemimageimport.sh -p $scomp -v $sver -s -i $SM_INSTIMAGEFILENAME $log_args"
			set +x
			RESULT=`${TBSMBINDIR}/gemimageimport.sh -p "$scomp" -v "$sver" -s -i "$SM_INSTIMAGEFILENAME" $args` 
			rc=$?
			echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
   			set -x
   			checkrc $rc

   			echo "${TBSMBINDIR}/gemimageimport.sh -p $scomp -v $sver -l -i $LG_INSTIMAGEFILENAME $log_args"
   			set +x 
   			RESULT=`${TBSMBINDIR}/gemimageimport.sh -p "$scomp" -v "$sver" -l -i "$LG_INSTIMAGEFILENAME" $args`
   			rc=$?
 			echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
   			set -x
   			checkrc $rc
  		fi

  		# Add Software Component to the Line of Business
  		echo "${TBSMBINDIR}/addpvToLOB.sh -p $scomp -v $sver -l $LOBNAME $log_args"
  		set +x
  		RESULT=`${TBSMBINDIR}/addpvToLOB.sh -p "$scomp" -v "$sver" -l "$LOBNAME" $args`
  		rc=$?
  		echo "$RESULT" | sed "s/-P $6/-P xxxxxxxx/g"
  		set -x
  		checkrc $rc

  		echo "${TBSMBINDIR}/updateLOBview.sh $log_args"
  		set +x
  		RESULT=`${TBSMBINDIR}/updateLOBview.sh $args`
  		rc=$?
  		echo "$RESULT"
  		set -x
  		checkrc $rc

	done
done

rm $WORKDIR/*.out
rm $WORKDIR/*.gif
#rm $WORKDIR/*.tll
rm $WORKDIR/*.cid
rm $WORKDIR/*.sqi
rm $WORKDIR/*.sql

${TBSMBINDIR}/ASIShellMsg ASIBldScripts 8

exit 0
