#!/bin/ksh
#
# ITMOracle_uninstall_tbsm.sh v1.0
#
# Description: Uninstall IBM Tivoli Monitoring for Databases, Version 5.1.0 - Oracle: TBSM Integration
#
# NOTE: Must be run on the TBSM server under from the MKS Korn shell.
#
#
# (C) COPYRIGHT IBM, Inc. 2002
# All Rights Reserved
# Licensed Material - Property of IBM, Inc.
#
# Parameters:
# -S hostname of the sql server
# -U user id
# -P password
#

# -------
COMPANY="IBM"

SOFTCOMP="OracleInstanceManager OracleDatabaseManager"
SOFTCOMP_VERSIONS="7.3.4 8.0.4 8.0.5 8.1.5 8.1.6 8.1.7 9.0.1 9.0.2 9.2.0 unknown"

SM_INSTIMAGEFILENAME="tv_oracle_database_instance_24.gif"
LG_INSTIMAGEFILENAME="tv_oracle_database_instance_45.gif"
SM_DBIMAGEFILENAME="tv_oracle_database_24.gif"
LG_DBIMAGEFILENAME="tv_oracle_database_45.gif"

PARENTLOBNAME="IBM"
LOBNAME="Oracle Databases"

# Exit if non-zero return code
# TBSM scripts will explain the error

function checkrc {
	if [ $1 -ne 0 ]
	then
    	exit $1
	fi
}

# Create a working directory and copy our files there
# Set log 
WORKDIR="C:/temp/CTO"			# Use your ADA here
LOG="${WORKDIR}/trace_ITMOracle_uninstall_tbsm.log"
if [ ! -d $WORKDIR ] 
then
	mkdir $WORKDIR
	checkrc $?
fi

exec 2>$LOG
set -x

cd $WORKDIR

# Set directory names based on where TBSM is installed
TBSMDIR=`reg query 'HKLM\Software\Accessible Software, Inc.\Access1\1.0\InstallDirectory' | sed 's/^.*InstallDirectory[        ]*//'`
echo "TBSM dir is $TBSMDIR"

TBSMBINDIR="${TBSMDIR}/bin"
TLLBINDIR="${TBSMDIR}/xdfparser/bin"

PATH="$PATH;$TBSMBINDIR;$TLLBINDIR"
export PATH

# Check Usage
# On failure, use a TBSM translated message but strip out the []. 
# Our usage is:
#
# $0 -S server -U userid -P password

if [ "$1" != "-S" ] || [ "$3" != "-U" ] || [ "$5" != "-P" ] || [ "$6" = "" ]
then
	echo
	${TBSMBINDIR}/ASIShellMsg ASILobScripts 15 $0 | sed 's/\[//g' | sed 's/\]//g'
	echo
	exit 1
fi

# We will pass in all the command line arguments to each command that needs them
set +x
args="$*"
# Do not put password in the log file
log_args="$1 $2 $3 $4 $5 xxxxxxxx"
set -x

# Stop the Application Server service

${TBSMBINDIR}/sc stop ASIApplicationSvc

sleep 10

# Loop for each Software Component Version

for scomp in $SOFTCOMP
do

	for sver in $SOFTCOMP_VERSIONS
	do
		# Remove Software Component from the Line of Business
		cmd="addpvToLOB.sh -p "$scomp" -v "$sver" -l "$LOBNAME" $log_args -a delete"
		set +x
		${TBSMBINDIR}/addpvToLOB.sh -p "$scomp" -v "$sver" -l "$LOBNAME" $args -a "delete"
		rc=$?
		set -x
		checkrc $rc

		# Delete software components
		cmd="tbsmsql.exe -MCONSOLE -r -dObject $log_args -Q exec gemsp_delete_product @prodname='$scomp', @version='$sver'"
		set +x
		${TBSMBINDIR}/tbsmsql.exe -MCONSOLE -r -dObject $args -Q"exec gemsp_delete_product @prodname='$scomp', @version='$sver'"
		rc=$?
		set -x
		checkrc $rc
    
		#######################
		# need to remove the images, do not have a way
		#######################

	done
done

# Restart the Application Server service

${TBSMBINDIR}/sc start ASIApplicationSvc

sleep 10

# Remove Line of Business - ignore the return codes
cmd="rmLOB.sh -l "$LOBNAME" -p "$PARENTLOBNAME" $log_args"
set +x
${TBSMBINDIR}/rmLOB.sh -l "$LOBNAME" -p "$PARENTLOBNAME" $args
set -x
  
cmd="rmLOB.sh -l "$PARENTLOBNAME" $log_args"
set +x
${TBSMBINDIR}/rmLOB.sh -l "$PARENTLOBNAME" $args
set -x
  
cmd="updateLOBview.sh $log_args"
set +x
${TBSMBINDIR}/updateLOBview.sh $args
set -x
  

# Clean up files
rm $WORKDIR/*.out
#rm $WORKDIR/*.sql
#rm $WORKDIR/*.msg
rm $WORKDIR/trace_ITMOracle_init_TBSM.log
